# ConversationId

Conversation ID to filter on

## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------

## Example

```python
from _generated.models.conversation_id import ConversationId

# TODO update the JSON string below
json = "{}"
# create an instance of ConversationId from a JSON string
conversation_id_instance = ConversationId.from_json(json)
# print the JSON string representation of the object
print(ConversationId.to_json())

# convert the object into a dict
conversation_id_dict = conversation_id_instance.to_dict()
# create an instance of ConversationId from a dict
conversation_id_from_dict = ConversationId.from_dict(conversation_id_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


